import _extends from "@babel/runtime/helpers/extends";

/** @jsx jsx */
import { css, jsx } from '@emotion/core';
import { SPACING_SCALE } from '../constants';
const borderRadiusMap = {
  normal: css({
    borderRadius: '3px'
  }),
  rounded: css({
    borderRadius: '50%'
  }),
  badge: css({
    borderRadius: '8px'
  })
};
const flexDirectionMap = {
  column: css({
    flexDirection: 'column'
  }),
  row: css({
    flexDirection: 'row'
  })
};
const flexAlignMap = {
  center: css({
    alignItems: 'center'
  }),
  baseline: css({
    alignItems: 'baseline'
  })
};
const displayMap = {
  flex: css({
    display: 'flex'
  }),
  inline: css({
    display: 'inline'
  }),
  inlineFlex: css({
    display: 'inline-flex'
  })
};
/**
 * __Box__
 *
 * A Box {description}.
 *
 * @internal
 */

function Box({
  children,
  as: Component = 'div',
  backgroundColor,
  borderColor,
  borderRadius,
  alignItems,
  flexDirection,
  paddingBlock,
  paddingInline,
  gap,
  height,
  width,
  display = 'flex',
  // should this be the default? i've just set it as the default here to avoid breaking anyone's implem
  style,
  testId,

  /**
   * Pull this out to prevent accidentaly spread
   */
  // @ts-ignore
  // @eslint-disbale-next-line no-unused-vars
  className: dontUseThisProperty,
  ...htmlAttributes
}) {
  return jsx(Component, _extends({
    style: style // eslint-disable-next-line @repo/internal/react/no-unsafe-spread-props

  }, htmlAttributes, {
    css: [display && displayMap[display], paddingBlock && paddingBlockMap[paddingBlock], paddingInline && paddingInlineMap[paddingInline], alignItems && flexAlignMap[alignItems], backgroundColor && backgroundColorMap[backgroundColor], borderColor && borderColorMap[borderColor], borderRadius && borderRadiusMap[borderRadius], flexDirection && flexDirectionMap[flexDirection], gap && gapMap[gap], width && widthMap[width], height && heightMap[height]],
    "data-testid": testId
  }), children);
}

export default Box;
/**
 * THIS SECTION WAS CREATED VIA CODEGEN DO NOT MODIFY {@see http://go/af-codegen}
 * @codegen <<SignedSource::7bc92b308b72d1fe4aa9d758c2d1b073>>
 * @codegenId spacing
 * @codegenCommand yarn codegen-styles
 * @codegenParams ["paddingBlock", "paddingInline", "width", "height", "gap"]
 */

const paddingBlockMap = {
  'sp-25': css({
    paddingBlock: SPACING_SCALE['sp-25']
  }),
  'sp-50': css({
    paddingBlock: SPACING_SCALE['sp-50']
  }),
  'sp-75': css({
    paddingBlock: SPACING_SCALE['sp-75']
  }),
  'sp-100': css({
    paddingBlock: SPACING_SCALE['sp-100']
  }),
  'sp-200': css({
    paddingBlock: SPACING_SCALE['sp-200']
  }),
  'sp-300': css({
    paddingBlock: SPACING_SCALE['sp-300']
  }),
  'sp-400': css({
    paddingBlock: SPACING_SCALE['sp-400']
  }),
  'sp-600': css({
    paddingBlock: SPACING_SCALE['sp-600']
  }),
  'sp-800': css({
    paddingBlock: SPACING_SCALE['sp-800']
  })
};
const paddingInlineMap = {
  'sp-25': css({
    paddingInline: SPACING_SCALE['sp-25']
  }),
  'sp-50': css({
    paddingInline: SPACING_SCALE['sp-50']
  }),
  'sp-75': css({
    paddingInline: SPACING_SCALE['sp-75']
  }),
  'sp-100': css({
    paddingInline: SPACING_SCALE['sp-100']
  }),
  'sp-200': css({
    paddingInline: SPACING_SCALE['sp-200']
  }),
  'sp-300': css({
    paddingInline: SPACING_SCALE['sp-300']
  }),
  'sp-400': css({
    paddingInline: SPACING_SCALE['sp-400']
  }),
  'sp-600': css({
    paddingInline: SPACING_SCALE['sp-600']
  }),
  'sp-800': css({
    paddingInline: SPACING_SCALE['sp-800']
  })
};
const widthMap = {
  'sp-25': css({
    width: SPACING_SCALE['sp-25']
  }),
  'sp-50': css({
    width: SPACING_SCALE['sp-50']
  }),
  'sp-75': css({
    width: SPACING_SCALE['sp-75']
  }),
  'sp-100': css({
    width: SPACING_SCALE['sp-100']
  }),
  'sp-200': css({
    width: SPACING_SCALE['sp-200']
  }),
  'sp-300': css({
    width: SPACING_SCALE['sp-300']
  }),
  'sp-400': css({
    width: SPACING_SCALE['sp-400']
  }),
  'sp-600': css({
    width: SPACING_SCALE['sp-600']
  }),
  'sp-800': css({
    width: SPACING_SCALE['sp-800']
  })
};
const heightMap = {
  'sp-25': css({
    height: SPACING_SCALE['sp-25']
  }),
  'sp-50': css({
    height: SPACING_SCALE['sp-50']
  }),
  'sp-75': css({
    height: SPACING_SCALE['sp-75']
  }),
  'sp-100': css({
    height: SPACING_SCALE['sp-100']
  }),
  'sp-200': css({
    height: SPACING_SCALE['sp-200']
  }),
  'sp-300': css({
    height: SPACING_SCALE['sp-300']
  }),
  'sp-400': css({
    height: SPACING_SCALE['sp-400']
  }),
  'sp-600': css({
    height: SPACING_SCALE['sp-600']
  }),
  'sp-800': css({
    height: SPACING_SCALE['sp-800']
  })
};
const gapMap = {
  'sp-25': css({
    gap: SPACING_SCALE['sp-25']
  }),
  'sp-50': css({
    gap: SPACING_SCALE['sp-50']
  }),
  'sp-75': css({
    gap: SPACING_SCALE['sp-75']
  }),
  'sp-100': css({
    gap: SPACING_SCALE['sp-100']
  }),
  'sp-200': css({
    gap: SPACING_SCALE['sp-200']
  }),
  'sp-300': css({
    gap: SPACING_SCALE['sp-300']
  }),
  'sp-400': css({
    gap: SPACING_SCALE['sp-400']
  }),
  'sp-600': css({
    gap: SPACING_SCALE['sp-600']
  }),
  'sp-800': css({
    gap: SPACING_SCALE['sp-800']
  })
};
/**
 * @codegenEnd
 */

/**
 * THIS SECTION WAS CREATED VIA CODEGEN DO NOT MODIFY {@see http://go/af-codegen}
 * @codegen <<SignedSource::f48a8ffccf0c385e9e05322037509c45>>
 * @codegenId colors
 * @codegenCommand yarn codegen-styles
 * @codegenParams ["border", "background"]
 */

const borderColorMap = {
  default: css({
    borderColor: "var(--ds-border, #091E4224)"
  }),
  bold: css({
    borderColor: "var(--ds-border-bold, #758195)"
  }),
  inverse: css({
    borderColor: "var(--ds-border-inverse, #FFFFFF)"
  }),
  focused: css({
    borderColor: "var(--ds-border-focused, #388BFF)"
  }),
  input: css({
    borderColor: "var(--ds-border-input, #091E4224)"
  }),
  disabled: css({
    borderColor: "var(--ds-border-disabled, #091E420F)"
  }),
  brand: css({
    borderColor: "var(--ds-border-brand, #0C66E4)"
  }),
  selected: css({
    borderColor: "var(--ds-border-selected, #0C66E4)"
  }),
  danger: css({
    borderColor: "var(--ds-border-danger, #E34935)"
  }),
  warning: css({
    borderColor: "var(--ds-border-warning, #D97008)"
  }),
  success: css({
    borderColor: "var(--ds-border-success, #22A06B)"
  }),
  discovery: css({
    borderColor: "var(--ds-border-discovery, #8270DB)"
  }),
  information: css({
    borderColor: "var(--ds-border-information, #1D7AFC)"
  })
};
const backgroundColorMap = {
  disabled: css({
    backgroundColor: "var(--ds-background-disabled, #091E4208)"
  }),
  'inverse.subtle': css({
    backgroundColor: "var(--ds-background-inverse-subtle, #00000029)"
  }),
  input: css({
    backgroundColor: "var(--ds-background-input, #FFFFFF)"
  }),
  neutral: css({
    backgroundColor: "var(--ds-background-neutral, #091E420F)"
  }),
  'neutral.subtle': css({
    backgroundColor: "var(--ds-background-neutral-subtle, #00000000)"
  }),
  'neutral.bold': css({
    backgroundColor: "var(--ds-background-neutral-bold, #44546F)"
  }),
  'brand.bold': css({
    backgroundColor: "var(--ds-background-brand-bold, #0C66E4)"
  }),
  selected: css({
    backgroundColor: "var(--ds-background-selected, #E9F2FF)"
  }),
  'selected.bold': css({
    backgroundColor: "var(--ds-background-selected-bold, #0C66E4)"
  }),
  danger: css({
    backgroundColor: "var(--ds-background-danger, #FFEDEB)"
  }),
  'danger.bold': css({
    backgroundColor: "var(--ds-background-danger-bold, #CA3521)"
  }),
  warning: css({
    backgroundColor: "var(--ds-background-warning, #FFF7D6)"
  }),
  'warning.bold': css({
    backgroundColor: "var(--ds-background-warning-bold, #E2B203)"
  }),
  success: css({
    backgroundColor: "var(--ds-background-success, #DFFCF0)"
  }),
  'success.bold': css({
    backgroundColor: "var(--ds-background-success-bold, #1F845A)"
  }),
  discovery: css({
    backgroundColor: "var(--ds-background-discovery, #F3F0FF)"
  }),
  'discovery.bold': css({
    backgroundColor: "var(--ds-background-discovery-bold, #6E5DC6)"
  }),
  information: css({
    backgroundColor: "var(--ds-background-information, #E9F2FF)"
  }),
  'information.bold': css({
    backgroundColor: "var(--ds-background-information-bold, #0C66E4)"
  })
};
/**
 * @codegenEnd
 */