/** @jsx jsx */
import { CSSProperties, ElementType, HTMLAttributes, ReactNode } from 'react';
import { GlobalSpacingToken } from '../constants';
export interface BoxProps extends HTMLAttributes<HTMLElement> {
    /**
     * The DOM element to render as the Box. Defaults to `div`.
     */
    as?: ElementType;
    /**
     * A unique string that appears as data attribute `data-testid` in the rendered code, serving as a hook for automated tests.
     */
    testId?: string;
    children: ReactNode;
    /**
     * Token representing background color.
     */
    backgroundColor?: BackgroundColor;
    /**
     * Token representing border color. When a border color is provided, border styles default to `2px solid`. This can be overriden with `styles`.
     */
    borderColor?: BorderColor;
    /**
     * The flex property
     */
    justifyContent?: CSSProperties['justifyContent'];
    /**
     * The flex property
     */
    flexDirection?: keyof typeof flexDirectionMap;
    /**
     * The flex property
     */
    alignItems?: keyof typeof flexAlignMap;
    borderRadius?: BorderRadius;
    paddingBlock?: GlobalSpacingToken;
    paddingInline?: GlobalSpacingToken;
    width?: GlobalSpacingToken;
    height?: GlobalSpacingToken;
    gap?: GlobalSpacingToken;
    display?: Display;
}
declare type BorderRadius = keyof typeof borderRadiusMap;
declare const borderRadiusMap: {
    normal: import("@emotion/utils").SerializedStyles;
    rounded: import("@emotion/utils").SerializedStyles;
    badge: import("@emotion/utils").SerializedStyles;
};
declare const flexDirectionMap: {
    column: import("@emotion/utils").SerializedStyles;
    row: import("@emotion/utils").SerializedStyles;
};
declare const flexAlignMap: {
    center: import("@emotion/utils").SerializedStyles;
    baseline: import("@emotion/utils").SerializedStyles;
};
declare type Display = keyof typeof displayMap;
declare const displayMap: {
    flex: import("@emotion/utils").SerializedStyles;
    inline: import("@emotion/utils").SerializedStyles;
    inlineFlex: import("@emotion/utils").SerializedStyles;
};
/**
 * __Box__
 *
 * A Box {description}.
 *
 * @internal
 */
declare function Box({ children, as: Component, backgroundColor, borderColor, borderRadius, alignItems, flexDirection, paddingBlock, paddingInline, gap, height, width, display, // should this be the default? i've just set it as the default here to avoid breaking anyone's implem
style, testId, 
/**
 * Pull this out to prevent accidentaly spread
 */
className: dontUseThisProperty, ...htmlAttributes }: BoxProps): JSX.Element;
export default Box;
/**
 * @codegenEnd
 */
/**
 * THIS SECTION WAS CREATED VIA CODEGEN DO NOT MODIFY {@see http://go/af-codegen}
 * @codegen <<SignedSource::f48a8ffccf0c385e9e05322037509c45>>
 * @codegenId colors
 * @codegenCommand yarn codegen-styles
 * @codegenParams ["border", "background"]
 */
declare const borderColorMap: {
    default: import("@emotion/utils").SerializedStyles;
    bold: import("@emotion/utils").SerializedStyles;
    inverse: import("@emotion/utils").SerializedStyles;
    focused: import("@emotion/utils").SerializedStyles;
    input: import("@emotion/utils").SerializedStyles;
    disabled: import("@emotion/utils").SerializedStyles;
    brand: import("@emotion/utils").SerializedStyles;
    selected: import("@emotion/utils").SerializedStyles;
    danger: import("@emotion/utils").SerializedStyles;
    warning: import("@emotion/utils").SerializedStyles;
    success: import("@emotion/utils").SerializedStyles;
    discovery: import("@emotion/utils").SerializedStyles;
    information: import("@emotion/utils").SerializedStyles;
};
declare type BorderColor = keyof typeof borderColorMap;
declare const backgroundColorMap: {
    disabled: import("@emotion/utils").SerializedStyles;
    'inverse.subtle': import("@emotion/utils").SerializedStyles;
    input: import("@emotion/utils").SerializedStyles;
    neutral: import("@emotion/utils").SerializedStyles;
    'neutral.subtle': import("@emotion/utils").SerializedStyles;
    'neutral.bold': import("@emotion/utils").SerializedStyles;
    'brand.bold': import("@emotion/utils").SerializedStyles;
    selected: import("@emotion/utils").SerializedStyles;
    'selected.bold': import("@emotion/utils").SerializedStyles;
    danger: import("@emotion/utils").SerializedStyles;
    'danger.bold': import("@emotion/utils").SerializedStyles;
    warning: import("@emotion/utils").SerializedStyles;
    'warning.bold': import("@emotion/utils").SerializedStyles;
    success: import("@emotion/utils").SerializedStyles;
    'success.bold': import("@emotion/utils").SerializedStyles;
    discovery: import("@emotion/utils").SerializedStyles;
    'discovery.bold': import("@emotion/utils").SerializedStyles;
    information: import("@emotion/utils").SerializedStyles;
    'information.bold': import("@emotion/utils").SerializedStyles;
};
declare type BackgroundColor = keyof typeof backgroundColorMap;
/**
 * @codegenEnd
 */
